==> frock-1.1.1.tgz: package/lib/register-handler.js <==
'use strict';

/**
 * Copyright 2015 Urban Airship Inc. and Contributors. Subject to the LICENSE
 * file at the top-level directory of this distribution and at
 * https://github.com/urbanairship/frock/blob/master/LICENSE
 */
var bole = require('bole');

var _require2 = require('resolve');

var resolve = _require2.sync;

var semver = require('semver');

var _require3 = require('interpret');

var extensions = _require3.extensions;

var rechoir = require('rechoir');

var pkg = require('../package.json');

var log = bole('frock/register-handler');

module.exports = createHandlerRegister;

function createHandlerRegister(pwd) {
  var _require = arguments.length <= 1 || arguments[1] === undefined ? require : arguments[1];

  var handlers = new Map();
  var paths = new Map();

  handlers.register = register;
  handlers.destroy = destroy;

  return handlers;

  function register(name) {
    if (handlers.has(name)) {
      return handlers.get(name);
    }

    var handlerPath = resolve(name, { basedir: pwd });

    try {
      rechoir.prepare(extensions, handlerPath);
    } catch (e) {
      // pass, but log the error
      log.error('Error preparing transform for ' + name + '\n  ' + e.message);
    }

    var handler = _require(handlerPath);

    handlers.set(name, handler);
    paths.set(name, handlerPath);

    // only perform package version checks for installable mocks
    if (handlerPath.includes('node_modules')) {
      var pkgPath = undefined;
      var lpkg = undefined;

      try {
        pkgPath = resolve(name.replace(/\/$/, '') + '/package.json', { basedir: pwd });
        lpkg = _require(pkgPath);
      } catch (e) {
        log.debug('unable to require path ' + e.message);
      }

      if (lpkg && lpkg.frock && lpkg.frock['compatible-versions']) {
        var compat = lpkg.frock['compatible-versions'];

        if (!semver.satisfies(pkg.version, compat)) {
          log.warn('handler ' + name + ' claims compatibility with ' + compat + ', but you ' + ('are using frock version ' + pkg.version + '. You may experience ') + 'unexpected behavior.');
        }
      } else {
        log.warn('handler ' + name + ' did not specify its compatible frock versions!');
      }
    }

    log.debug('registered handler ' + name);

    return handler;
  }

  function destroy() {
    log.debug('unloading all required handlers');

    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = paths.values()[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var val = _step.value;

        delete _require.cache[val];
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    handlers.clear();
    paths.clear();
  }
}

==> frock-3.0.0.tgz: package/lib/register-handler.js <==
'use strict';

/**
 * Copyright 2015 Urban Airship Inc. and Contributors. Subject to the LICENSE
 * file at the top-level directory of this distribution and at
 * https://github.com/urbanairship/frock/blob/master/LICENSE
 */
var bole = require('bole');

var _require2 = require('resolve'),
    resolve = _require2.sync;

var semver = require('semver');

var _require3 = require('interpret'),
    extensions = _require3.extensions;

var rechoir = require('rechoir');

var pkg = require('../package.json');

var log = bole('frock/register-handler');

module.exports = createHandlerRegister;

function createHandlerRegister(pwd) {
  var _require = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : require;

  var handlers = new Map();
  var paths = new Map();

  handlers.register = register;
  handlers.destroy = destroy;

  return handlers;

  function register(name) {
    if (handlers.has(name)) {
      return handlers.get(name);
    }

    var handlerPath = resolve(name, { basedir: pwd });

    try {
      rechoir.prepare(extensions, handlerPath);
    } catch (e) {
      // pass, but log the error
      log.error('Error preparing transform for ' + name + '\n  ' + e.message);
    }

    var handler = _require(handlerPath);

    handlers.set(name, handler);
    paths.set(name, handlerPath);

    // only perform package version checks for installable mocks
    if (handlerPath.includes('node_modules')) {
      var pkgPath = void 0;
      var lpkg = void 0;

      try {
        pkgPath = resolve(name.replace(/\/$/, '') + '/package.json', { basedir: pwd });
        lpkg = _require(pkgPath);
      } catch (e) {
        log.debug('unable to require path ' + e.message);
      }

      if (lpkg && lpkg.frock && lpkg.frock['compatible-versions']) {
        var compat = lpkg.frock['compatible-versions'];

        if (!semver.satisfies(pkg.version, compat)) {
          log.warn('handler ' + name + ' claims compatibility with ' + compat + ', but you ' + ('are using frock version ' + pkg.version + '. You may experience ') + 'unexpected behavior.');
        }
      } else {
        log.warn('handler ' + name + ' did not specify its compatible frock versions!');
      }
    }

    log.debug('registered handler ' + name);

    return handler;
  }

  function destroy() {
    log.debug('unloading all required handlers');

    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = paths.values()[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var val = _step.value;

        delete _require.cache[val];
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    handlers.clear();
    paths.clear();
  }
}
